@@ -2,6 +2,7 @@ import os
 from dotenv import load_dotenv
 from google import genai
 from git import Repo
+from .configure import get_configured_model
 
 def gerar_mensagem_commit():
     load_dotenv()
@@ -9,8 +10,8 @@ def gerar_mensagem_commit():
     if not key:
         raise RuntimeError("The GEMINI_API_KEY environment variable is not set.")
 
-    #genai.configure(api_key=key)
-    #model = genai.GenerativeModel("gemini-2.0-flash")
+    # Get the configured model
+    model = get_configured_model()
 
     client = genai.Client(api_key=key)
     
@@ -39,7 +40,7 @@ def gerar_mensagem_commit():
     )
 
     response = client.models.generate_content(
-        model="gemini-2.0-flash",
+        model=model,
         contents=prompt
     )
-    return response.text.strip()
\ No newline at end of file
+    return response.text.strip() if response.text else "Failed to generate commit message"
\ No newline at end of file
